#
# spec file for package redis++
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
Name:           redis++
Version:        1.3.12
Release:        2.1
Summary:        C++ client for Redis
License:        Apache-2.0
URL:            https://github.com/sewenew/redis-plus-plus
Source0:        https://github.com/sewenew/redis-plus-plus/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.5
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(hiredis)
BuildRequires:  pkgconfig(hiredis_ssl)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(openssl)

%description
Redis-plus-plus, a C++ client for Redis based on hiredis and written in C++11/C++17.

%package -n lib%{name}%{sover}
Summary:        C++ client for Redis

%description -n lib%{name}%{sover}
Redis-plus-plus, a C++ client for Redis based on hiredis and written in C++11/C++17.

%package devel
Summary:        Header files and libraries for %{name}
Requires:       lib%{name}%{sover} = %{version}
# With version 1.3, proper so-versioning was added, which made the .so a pure devel symlink
# For this reason though we conflict with older, unversioned libraries
Conflicts:      lib%{name} < 1.3

%description devel
The %{name}-devel package contains the header files and
libraries for redis-plus-plus.

%prep
%autosetup -n redis-plus-plus-%{version}

%build
sed -i -e '/DESTINATION.*/s/lib/%{_lib}/' CMakeLists.txt
%cmake \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCMAKE_SHARED_LINKER_FLAGS="%{?build_ldflags}" \
  -DREDIS_PLUS_PLUS_BUILD_STATIC=OFF \
  -DREDIS_PLUS_PLUS_USE_TLS=ON \
  -DREDIS_PLUS_PLUS_BUILD_TEST=OFF \
  -DREDIS_PLUS_PLUS_BUILD_ASYNC="libuv" \
  -DCMAKE_POLICY_VERSION_MINIMUM=3.5
%cmake_build

%install
%cmake_install

%check
%ctest

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%license LICENSE
%doc README.md
%{_libdir}/libredis++.so.%{sover}{,.*}

%files devel
%license LICENSE
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libredis++.so
%{_datadir}/cmake/redis++
%{_includedir}/sw

%changelog
* Sat Mar 22 2025 Shawn Dunn <sfalken@opensuse.org>
- Add -DCMAKE_POLICY_VERSION_MINIMUM=3.5 to fix FTBFS with cmake4
* Mon May  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.3.12:
  * Fix memory leak problem of AsyncRedisCluster
* Tue Jan  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.3.11:
  * Fix redlock to make multiple threads be able to lock on the same RedMutex
  * Asynchronously update slot-node mapping in some edge cases
  * Use weak_ptr to avoid joining EvenLoop thread in itself
  * Support setting connection name
  * Support shard pub/sub
* Thu Aug 24 2023 Martin Pluskal <mpluskal@suse.com>
- Update URL
* Sat Jul 29 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3.10:
  * Fix TLS support on async interface
- update to 1.3.9:
  * Fix async interface bug
  * More built-in commands support for AsyncRedis
  * Fix incorrect hiredis static lib dependency when building with
    TSL
  * Breaking change: make HSET related methods return long long
    instead of bool
* Sat May 20 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 1.3.8:
  * Fix memory for async interface
  * Support sending commands that have no keys, to Redis Cluster in
    async mode
  * Support verify mode for TLS support, so we can skip certificate
    verification
  * Support keepalive with customized interval
- drop fix-missing-include.patch includes upstream
* Sat Apr  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-missing-include.patch: Fix missing include exposed by gcc
  13.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.7:
  * Optimize connection creation
  * ACL and RESP3 support for sentinel
  * Async interface bug fixes
  * Better error message for sentinel
  * Better URI support
  * RESP3 bug fix
* Tue Oct 25 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3.6:
  * RESP3 support
  * Redlock support
  * Timeout support for async interface
* Sun Oct  9 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3.5:
  * Ensure running async callback when error happens
  * Add sentinel support for coroutine interface
  * Add publish command for async interface
- includes changes from 1.3.4:
  * Add async support for subscriber
  * Add async support with callbacks
  * Add coroutine support
* Wed Feb  2 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Have the -devel package conflict with libredis++ < 1.3: newly,
  the library is versioned, which results in the old, unversioned
  library conflicting with the new .so symlink.
* Tue Jan 25 2022 Martin Pluskal <mpluskal@suse.com>
- Small spec file cleanup
* Mon Dec 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3.3:
  * Support async interface
  * Support max connection idle time
- drop patches:
  * custom_install_locations.patch
  * disable_static_lib.patch
  * use_shared_lib_for_test.patch
* Fri Oct  9 2020 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file
* Wed Sep 30 2020 paul.fee@jci.com
- Package redis++ 1.0.0 for openSUSE
- disable_static_lib.patch
  Upstream commit: master 10c3e8242812696bc3d965e033d132cbdac1d11d
  13 Sep 2020
  Add cmake options to disable building static lib or shared lib.
  Used here since only shared library is packaged.
- use_shared_lib_for_test.patch
  Link against shared libraries provided by hiredis package.
- custom_install_locations.patch
  Provide CMake options for custom library and header file locations.
  For example lib64 on x86_64 and lib on i586.
